import { ChoroplethLayer } from './choropleth-layer/newChoroplethLayer';
import { HeatLayer } from './heatmap-layer/HeatLayer';
import { NodeLinkLayer } from './nodelink-layer/NodeLinkLayer';
import { NodeLayer } from './node-layer/NodeLayer';
import { NodeIconLayer } from './icon-layer/IconLayer';
import NodeOptions from './node-layer/NodeOptions';
import NodeLinkOptions from './nodelink-layer/NodeLinkOptions';
import IconOptions from './icon-layer/IconOptions';
import HeatLayerOptions from './heatmap-layer/HeatLayerOptions';
import ChoroplethOptions from './choropleth-layer/ChoroplethOptions';
import { TileLayer, BitmapLayer } from 'deck.gl';

export const layerTypes: Record<string, any> = {
  node: NodeLayer,
  icon: NodeIconLayer,
  nodelink: NodeLinkLayer,
  heatmap: HeatLayer,
  // choropleth: ChoroplethLayer,
};

export const layerSettings: Record<string, any> = {
  node: NodeOptions,
  nodelink: NodeLinkOptions,
  icon: IconOptions,
  heatmap: HeatLayerOptions,
  // choropleth: ChoroplethOptions,
};

const MAP_PROVIDER = [
  'https://a.tile.openstreetmap.org/{z}/{x}/{y}.png',
  'https://b.tile.openstreetmap.org/{z}/{x}/{y}.png',
  'https://c.tile.openstreetmap.org/{z}/{x}/{y}.png',
];

export const createBaseMap = () => {
  return new TileLayer({
    data: MAP_PROVIDER,
    minZoom: 0,
    maxZoom: 19,
    tileSize: 256,

    renderSubLayers: (props: any) => {
      const {
        bbox: { west, south, east, north },
      } = props.tile;

      return new BitmapLayer(props, {
        data: undefined,
        image: props.data,
        bounds: [west, south, east, north],
      });
    },
  });
};
