import React from 'react';
import { Meta } from '@storybook/react';
import { Provider } from 'react-redux';
import { configureStore } from '@reduxjs/toolkit';
import { graphQueryResultSlice, querybuilderSlice, schemaSlice, visualizationSlice } from '../../../data-access/store';
import { MapComponent } from './mapvis';
import { mockData } from '../../../mock-data/query-result/mockData';

const Mockstore = configureStore({
  reducer: {
    schema: schemaSlice.reducer,
    graphQueryResult: graphQueryResultSlice.reducer,
    visualize: visualizationSlice.reducer,
    querybuilder: querybuilderSlice.reducer,
  },
});

const Component: Meta<typeof MapComponent.component> = {
  title: 'Visualizations/MapVis',
  component: MapComponent.component,
  decorators: [
    (story) => (
      <Provider store={Mockstore}>
        <div
          style={{
            width: '100%',
            height: '100vh',
          }}
        >
          {story()}
        </div>
      </Provider>
    ),
  ],
};

export const Node = {
  args: {
    ...(await mockData.mockMobilityQueryResult()),
    settings: {
      layer: 'node',
      parkings: {
        color: [6, 147, 227],
        fixed: true,
        hidden: false,
        lat: 'lat',
        lon: 'long',
        max: 10,
        min: 0,
        radius: 1,
        sizeAttribute: '',
      },
      rides: {
        color: [6, 147, 227],
        fixed: true,
        hidden: false,
        max: 10,
        min: 0,
        width: 1,
        widthAttribute: '',
      },
    },
  },
};

export const Icon = {
  args: {
    ...(await mockData.mockMobilityQueryResult()),
    settings: {
      layer: 'icon',
      parkings: {
        color: [6, 147, 227],
        fixed: true,
        hidden: false,
        lat: 'lat',
        lon: 'long',
        max: 10,
        min: 0,
        radius: 1,
        sizeAttribute: '',
      },
      rides: {
        color: [6, 147, 227],
        fixed: true,
        hidden: false,
        max: 10,
        min: 0,
        width: 1,
        widthAttribute: '',
      },
    },
  },
};

export const NodeLink = {
  args: {
    ...(await mockData.mockMobilityQueryResult()),
    settings: {
      layer: 'nodelink',
      parkings: {
        color: [6, 147, 227],
        fixed: true,
        hidden: false,
        lat: 'lat',
        lon: 'long',
        max: 10,
        min: 0,
        radius: 1,
        sizeAttribute: '',
      },
      rides: {
        color: [6, 147, 227],
        fixed: true,
        hidden: false,
        max: 10,
        min: 0,
        width: 1,
        widthAttribute: '',
      },
    },
  },
};

export const Heatmap = {
  args: {
    ...(await mockData.mockMobilityQueryResult()),
    settings: {
      layer: 'heatmap',
      parkings: {
        color: [6, 147, 227],
        fixed: true,
        hidden: false,
        lat: 'lat',
        lon: 'long',
        max: 10,
        min: 0,
        radius: 1,
        sizeAttribute: '',
      },
      rides: {
        color: [6, 147, 227],
        fixed: true,
        hidden: false,
        max: 10,
        min: 0,
        width: 1,
        widthAttribute: '',
      },
    },
  },
};

export default Component;
