import React from 'react';
import { Meta } from '@storybook/react';
import { graphQueryResultSlice, querybuilderSlice, schemaSlice, visualizationSlice } from '../../../data-access/store';
import { configureStore } from '@reduxjs/toolkit';
import { Provider } from 'react-redux';
import { big2ndChamberSchemaRaw, marieBoucherSampleSchemaRaw, simpleSchemaAirportRaw, mockData } from '../../../mock-data';
import PaohVisComponent from './paohvis';

const Mockstore = configureStore({
  reducer: {
    schema: schemaSlice.reducer,
    graphQueryResult: graphQueryResultSlice.reducer,
    visualize: visualizationSlice.reducer,
    querybuilder: querybuilderSlice.reducer,
  },
});

const Component: Meta<typeof PaohVisComponent.component> = {
  title: 'Visualizations/Paohvis',
  component: PaohVisComponent.component,
  decorators: [
    (story) => (
      <Provider store={Mockstore}>
        <div
          style={{
            width: '100%',
            height: '100vh',
          }}
        >
          {story()}
        </div>
      </Provider>
    ),
  ],
};

export const TestWithMarieBoucherSample = {
  args: {
    ...(await mockData.marieBoucherSample()),
    updateSettings: () => {},
    schema: marieBoucherSampleSchemaRaw,
    settings: {
      ...PaohVisComponent.settings,
      rowNode: 'merchant',
      columnNode: 'merchant',
    },
  },
};

export const TestWithBig2ndChamber = {
  args: {
    ...(await mockData.big2ndChamberQueryResult()),
    updateSettings: () => {},
    schema: big2ndChamberSchemaRaw,
    settings: {
      ...PaohVisComponent.settings,
      rowNode: 'kamerleden',
      columnNode: 'commissies',
    },
  },
};

export const TestWithAirport = {
  args: {
    ...(await mockData.bigMockQueryResults()),
    updateSettings: () => {},
    schema: simpleSchemaAirportRaw,
    settings: {
      ...PaohVisComponent.settings,
      rowNode: 'airports',
      columnNode: 'airports',
    },
  },
};
/*
export const TestWithRecommendationsActorMovie = {
  args: {
    data: mockRecommendationsActorMovie,
    schema: marieBoucherSampleSchemaRaw,
    settings: PaohVisComponent.settings,
  },
};
*/
export default Component;
