import React from 'react';
import { Meta } from '@storybook/react';
import { graphQueryResultSlice, querybuilderSlice, schemaSlice, visualizationSlice } from '../../../data-access/store';
import { configureStore } from '@reduxjs/toolkit';
import { Provider } from 'react-redux';
import { big2ndChamberSchemaRaw, mockData, typesMockSchemaRaw } from '../../../mock-data';
import { simpleSchemaAirportRaw } from '../../../mock-data/schema/simpleAirportRaw';
import TableComponent from './tablevis';

const Mockstore = configureStore({
  reducer: {
    schema: schemaSlice.reducer,
    graphQueryResult: graphQueryResultSlice.reducer,
    visualize: visualizationSlice.reducer,
    querybuilder: querybuilderSlice.reducer,
  },
});

const Component: Meta<typeof TableComponent.component> = {
  title: 'Visualizations/TableVis',
  component: TableComponent.component,
  decorators: [
    (story) => (
      <Provider store={Mockstore}>
        <div
          style={{
            width: '100%',
            height: '100vh',
          }}
        >
          {story()}
        </div>
      </Provider>
    ),
  ],
};

export const TestWithAirport = {
  args: {
    ...(await mockData.bigMockQueryResults()),
    schema: simpleSchemaAirportRaw,
    settings: { ...TableComponent.settings, displayEntity: 'airports' },
  },
};

export const TestWithBig2ndChamber = {
  args: {
    ...(await mockData.big2ndChamberQueryResult()),
    schema: big2ndChamberSchemaRaw,
    settings: { ...TableComponent.settings, displayEntity: 'kamerleden' },
  },
};

export const TestWithTypesMock = {
  args: {
    ...(await mockData.typesMockQueryResults()),
    schema: typesMockSchemaRaw,
    settings: { ...TableComponent.settings, displayEntity: 'worker' },
  },
};

export default Component;
